==> emberware-vendia-groups-v1.0-389677.zip: backend/views/group-order/admin.php <==
<?php
use yii\widgets\Breadcrumbs;
use yii\helpers\Html;
use fedemotta\datatables\DataTables;
use emberware\vendia\groups\backend\Asset;


emberware\vendia\groups\backend\Asset::register($this);
/* @var $this yii\web\View */
/* @var $searchModel backend\models\GuestSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */
$this->title = $this->context->plural;
$this->params['breadcrumbs'][] = $this->title;

?>
<div class="group-order-index">
    <?=
    Breadcrumbs::widget(
        [
            'links' => isset($this->params['breadcrumbs']) ? $this->params['breadcrumbs'] : [],
        ]
    ) ?>
    <h1><?= Html::encode($this->title) ?></h1>

    <div class="order-aggregation">
        <?= Html::button('Importa ordini', [ 'class' => 'btn btn-primary', 'id' => 'import-orders'])?>
        <?= Html::button('Inizio settimana', [ 'class' => 'btn btn-success', 'id' => 'start-week'])?>
        <?= Html::button('Invia ordini di gruppo a woocommerce', [ 'class' => 'btn btn-success', 'id' => 'send-groups-orders'])?>
        <?= Html::button('Aggiungi nuovi ordini', [ 'class' => 'btn btn-primary', 'id' => 'import-join-send'])?>
        <?= Html::button('Aggrega ordini', [ 'class' => 'btn btn-primary', 'id' => 'order-aggregation'])?>
        <?= Html::button('Aggiorna ordini', [ 'class' => 'btn btn-primary', 'id' => 'update-group-orders'])?>
        <?= Html::button('Chiusura settimana', [ 'class' => 'btn btn-danger', 'id' => 'end-week'])?>
        <?= Html::button('Cancella ordini di gruppo', [ 'class' => 'btn btn-warning', 'id' => 'delete-group-orders-in-progress'])?>
        <input value="<?=$weekStatus?>" type="hidden" name="week-status" id="week-status">
    </div>

    <?= $this->render('_datatable_admin',[
            'query' => $query,
            // 'filterModel' => $searchModel,
            // 'searchProvider' => $searchProvider,
    ]) ?>
</div>

==> emberware-vendia-groups-v1.11-72a9a8.zip: backend/views/group-order/admin.php <==
<?php
use yii\widgets\Breadcrumbs;
use yii\helpers\Html;
use fedemotta\datatables\DataTables;
use emberware\vendia\groups\backend\Asset;


emberware\vendia\groups\backend\Asset::register($this);
/* @var $this yii\web\View */
/* @var $searchModel backend\models\GuestSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */
$this->title = $this->context->plural;
$this->params['breadcrumbs'][] = $this->title;

?>
<div class="group-order-index">
    <?=
    Breadcrumbs::widget(
        [
            'links' => isset($this->params['breadcrumbs']) ? $this->params['breadcrumbs'] : [],
        ]
    ) ?>
    <h1><?= Html::encode($this->title) ?></h1>

    <div class="order-aggregation">
        <?= Html::button('Importa ordini', [ 'class' => 'btn btn-primary', 'id' => 'import-orders'])?>
        <?= Html::button('Inizio settimana', [ 'class' => 'btn btn-success', 'id' => 'start-week'])?>        
        <?= Html::a('Crea nuovo ordine di gruppo', ['create'], ['class' => 'btn btn-primary', 'id' => 'create-group-order']) ?>
        <?= Html::button('Invia ordini di gruppo a woocommerce', [ 'class' => 'btn btn-success', 'id' => 'send-groups-orders'])?>
        <?= Html::button('Aggiungi nuovi ordini', [ 'class' => 'btn btn-primary', 'id' => 'import-join-send'])?>
        <?= Html::button('Aggrega ordini', [ 'class' => 'btn btn-primary', 'id' => 'order-aggregation'])?>
        <?= Html::button('Aggiorna ordini di gruppo a woocommerce', [ 'class' => 'btn btn-primary', 'id' => 'update-group-orders'])?>
        <?= Html::button('Chiusura settimana', [ 'class' => 'btn btn-danger', 'id' => 'end-week'])?>
        <?= Html::button('Cancella ordini di gruppo', [ 'class' => 'btn btn-warning', 'id' => 'delete-group-orders-in-progress'])?>
        <input value="<?=$weekStatus?>" type="hidden" name="week-status" id="week-status">
    </div>

    <?= $this->render('_datatable_admin',[
            'query' => $query,
            // 'filterModel' => $searchModel,
            // 'searchProvider' => $searchProvider,
    ]) ?>
</div>
